import { Box, Paper, Typography, IconButton } from '@mui/material';
import ArrowBackIcon from '@mui/icons-material/ArrowBack';
import type { GroupWithTasks, TaskWithSteps, StepWithNotes } from '../types';

function isGroupView(selectedGroup?: GroupWithTasks) {
  return !selectedGroup;
}

function isTaskView(selectedGroup?: GroupWithTasks, selectedTask?: TaskWithSteps) {
  return !!selectedGroup && !selectedTask;
}

function isStepView(selectedTask?: TaskWithSteps, selectedStep?: StepWithNotes) {
  return !!selectedTask && !selectedStep;
}

export function MobileLayout({
  groups = [],
  selectedGroup,
  selectedTask,
  selectedStep,
  onGroupSelect,
  onTaskSelect,
  onStepSelect,
  onBack,
}: {
  groups: GroupWithTasks[];
  selectedGroup?: GroupWithTasks;
  selectedTask?: TaskWithSteps;
  selectedStep?: StepWithNotes;
  onGroupSelect: (group: GroupWithTasks | undefined) => void;
  onTaskSelect: (task: TaskWithSteps | undefined) => void;
  onStepSelect: (step: StepWithNotes | undefined) => void;
  onBack: () => void;
}) {
  const groupList: GroupWithTasks[] = groups;
  const taskList: TaskWithSteps[] = (selectedGroup?.tasks as TaskWithSteps[]) ?? [];
  const stepList: StepWithNotes[] = (selectedTask?.steps as StepWithNotes[]) ?? [];

  return (
    <Box sx={{ height: '100vh', p: 2 }}>
      {/* Header with back button */}
      {selectedGroup && (
        <Box sx={{ display: 'flex', alignItems: 'center', mb: 2 }}>
          <IconButton onClick={onBack} sx={{ mr: 1 }}>
            <ArrowBackIcon />
          </IconButton>
          <Typography variant="h6">{selectedGroup.name}</Typography>
        </Box>
      )}

      {selectedTask && !selectedStep && (
        <Box sx={{ display: 'flex', alignItems: 'center', mb: 2 }}>
          <IconButton onClick={onBack} sx={{ mr: 1 }}>
            <ArrowBackIcon />
          </IconButton>
          <Typography variant="h6">{selectedTask.name}</Typography>
        </Box>
      )}

      {selectedStep && (
        <Box sx={{ display: 'flex', alignItems: 'center', mb: 2 }}>
          <IconButton onClick={onBack} sx={{ mr: 1 }}>
            <ArrowBackIcon />
          </IconButton>
          <Typography variant="h6">{selectedStep.name}</Typography>
        </Box>
      )}

      {/* Content */}
      <Paper sx={{ p: 2, overflow: 'auto', height: 'calc(100vh - 80px)' }}>
        {isGroupView(selectedGroup) && (
          <>
            <Typography variant="h6" gutterBottom>
              Groups
            </Typography>
            {groupList.map((group) => (
              <Box
                key={group.id}
                sx={{
                  p: 2,
                  cursor: 'pointer',
                }}
                onClick={() => onGroupSelect(group)}
              >
                <Typography>{group.name}</Typography>
              </Box>
            ))}
          </>
        )}

        {isTaskView(selectedGroup, selectedTask) && (
          <>
            <Typography variant="h6" gutterBottom>
              Tasks
            </Typography>
            <Box>
              {taskList.map((task) => (
                <Box
                  key={task.id}
                  sx={{
                    p: 2,
                    cursor: 'pointer',
                    bgcolor: selectedTask?.id === task.id ? 'action.selected' : 'transparent',
                  }}
                  onClick={() => onTaskSelect(task)}
                >
                  <Typography>{task.name}</Typography>
                </Box>
              ))}
            </Box>
          </>
        )}

        {isStepView(selectedTask, selectedStep) && (
          <>
            <Typography variant="h6" gutterBottom>
              Steps
            </Typography>
            <Box>
              {stepList.map((step) => (
                <Box
                  key={step.id}
                  sx={{
                    p: 2,
                    cursor: 'pointer',
                    bgcolor: selectedStep?.id === step.id ? 'action.selected' : 'transparent',
                  }}
                  onClick={() => onStepSelect(step)}
                >
                  <Typography>{step.name}</Typography>
                </Box>
              ))}
            </Box>
          </>
        )}
      </Paper>
    </Box>
  );
}