import { Group as SharedGroup, Task as SharedTask, Step as SharedStep, User as SharedUser, Note as SharedNote, PrintHistory as SharedPrintHistory } from '@task-receipts/shared';

// Client-specific type extensions
export interface GroupWithTasks extends Omit<SharedGroup, 'createdAt' | 'updatedAt'> {
  tasks: TaskWithSteps[];
}

export interface TaskWithSteps extends Omit<SharedTask, 'createdAt' | 'updatedAt' | 'lastPrintedAt'> {
  steps: StepWithNotes[];
  notes: NoteWithUser[];
  printCount: number;
  lastPrintedAt: string | null;
}

export interface StepWithNotes extends Omit<SharedStep, 'createdAt' | 'updatedAt' | 'lastPrintedAt'> {
  notes: NoteWithUser[];
  printCount: number;
  lastPrintedAt: string | null;
}

export interface NoteWithUser extends Omit<SharedNote, 'createdAt' | 'updatedAt'> {
  user?: SharedUser;
}

export interface PrintHistoryWithDetails extends Omit<SharedPrintHistory, 'createdAt' | 'updatedAt'> {
  user?: SharedUser;
  task?: TaskWithSteps;
  step?: StepWithNotes;
}

// Re-export shared types with client-specific modifications
export type Group = Omit<SharedGroup, 'createdAt' | 'updatedAt'>;
export type Task = Omit<SharedTask, 'createdAt' | 'updatedAt' | 'lastPrintedAt'> & { lastPrintedAt: string | null };
export type Step = Omit<SharedStep, 'createdAt' | 'updatedAt' | 'lastPrintedAt'> & { lastPrintedAt: string | null };
export type User = Omit<SharedUser, 'createdAt' | 'updatedAt'>;
export type Note = Omit<SharedNote, 'createdAt' | 'updatedAt'>;
export type PrintHistory = Omit<SharedPrintHistory, 'createdAt' | 'updatedAt'>;